var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
(function (factory) {
    if (typeof module === 'object' && typeof module.exports === 'object') {
        var v = factory(require, exports); if (v !== undefined) module.exports = v;
    }
    else if (typeof define === 'function' && define.amd) {
        define(["require", "exports", '@angular/core', '../ion', '../../config/config', '../../platform/platform'], factory);
    }
})(function (require, exports) {
    "use strict";
    var core_1 = require('@angular/core');
    var ion_1 = require('../ion');
    var config_1 = require('../../config/config');
    var platform_1 = require('../../platform/platform');
    var QUERY = {
        xs: '(min-width: 0px)',
        sm: '(min-width: 576px)',
        md: '(min-width: 768px)',
        lg: '(min-width: 992px)',
        xl: '(min-width: 1200px)',
        never: ''
    };
    /**
     * @private
     */
    var RootNode = (function () {
        function RootNode() {
        }
        return RootNode;
    }());
    exports.RootNode = RootNode;
    /**
     * @name SplitPane
     */
    var SplitPane = (function (_super) {
        __extends(SplitPane, _super);
        function SplitPane(_zone, _plt, config, elementRef, renderer) {
            _super.call(this, config, elementRef, renderer, 'split-pane');
            this._zone = _zone;
            this._plt = _plt;
            this._visible = false;
            this._init = false;
            this._mediaQuery = QUERY['md'];
            this.sideContent = null;
            this.mainContent = null;
            this.ionChange = new core_1.EventEmitter();
        }
        Object.defineProperty(SplitPane.prototype, "_setchildren", {
            set: function (query) {
                var _this = this;
                var children = this._children = query.filter((function (child) { return child !== _this; }));
                children.forEach(function (child) {
                    var isMain = child.initPane();
                    _this._setPaneCSSClass(child.getElementRef(), isMain);
                });
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(SplitPane.prototype, "when", {
            get: function () {
                return this._mediaQuery;
            },
            set: function (query) {
                if (typeof query === 'boolean') {
                    this._mediaQuery = query;
                }
                else {
                    var defaultQuery = QUERY[query];
                    this._mediaQuery = (defaultQuery)
                        ? defaultQuery
                        : query;
                }
                this._update();
            },
            enumerable: true,
            configurable: true
        });
        SplitPane.prototype._register = function (node, isMain, callback) {
            if (this.getElementRef().nativeElement !== node.getElementRef().nativeElement.parentNode) {
                return false;
            }
            this._setPaneCSSClass(node.getElementRef(), isMain);
            if (callback) {
                this.ionChange.subscribe(callback);
            }
            if (isMain) {
                if (this.mainContent) {
                    console.error('split pane: main content was already set');
                }
                this.mainContent = node;
            }
            return true;
        };
        SplitPane.prototype.ngAfterViewInit = function () {
            this._init = true;
            this._update();
        };
        SplitPane.prototype._update = function () {
            var _this = this;
            if (!this._init) {
                return;
            }
            // Unlisten
            this._rmListener && this._rmListener();
            this._rmListener = null;
            var query = this._mediaQuery;
            if (typeof query === 'boolean') {
                this._setVisible(query);
                return;
            }
            if (query && query.length > 0) {
                // Listen
                var callback_1 = function (query) { return _this._setVisible(query.matches); };
                var mediaList_1 = this._plt.win().matchMedia(query);
                mediaList_1.addListener(callback_1);
                this._setVisible(mediaList_1.matches);
                this._rmListener = function () {
                    mediaList_1.removeListener(callback_1);
                };
            }
            else {
                this._setVisible(false);
            }
        };
        SplitPane.prototype._updateChildren = function () {
            this.mainContent = null;
            this.sideContent = null;
            var visible = this._visible;
            this._children.forEach(function (child) { return child.paneChanged && child.paneChanged(visible); });
        };
        SplitPane.prototype._setVisible = function (visible) {
            var _this = this;
            if (this._visible === visible) {
                return;
            }
            this._visible = visible;
            this.setElementClass('split-pane-visible', visible);
            this._updateChildren();
            this._zone.run(function () {
                _this.ionChange.emit(_this);
            });
        };
        SplitPane.prototype.isVisible = function () {
            return this._visible;
        };
        SplitPane.prototype.setElementClass = function (className, add) {
            this._renderer.setElementClass(this._elementRef.nativeElement, className, add);
        };
        SplitPane.prototype._setPaneCSSClass = function (elementRef, isMain) {
            var ele = elementRef.nativeElement;
            this._renderer.setElementClass(ele, 'split-pane-main', isMain);
            this._renderer.setElementClass(ele, 'split-pane-side', !isMain);
        };
        SplitPane.prototype.ngOnDestroy = function () {
            (void 0) /* assert */;
            this._rmListener && this._rmListener();
            this._rmListener = null;
        };
        SplitPane.prototype.initPane = function () {
            return true;
        };
        SplitPane.decorators = [
            { type: core_1.Directive, args: [{
                        selector: 'ion-split-pane',
                        providers: [{ provide: RootNode, useExisting: core_1.forwardRef(function () { return SplitPane; }) }]
                    },] },
        ];
        /** @nocollapse */
        SplitPane.ctorParameters = [
            { type: core_1.NgZone, },
            { type: platform_1.Platform, },
            { type: config_1.Config, },
            { type: core_1.ElementRef, },
            { type: core_1.Renderer, },
        ];
        SplitPane.propDecorators = {
            '_setchildren': [{ type: core_1.ContentChildren, args: [RootNode, { descendants: false },] },],
            'when': [{ type: core_1.Input },],
            'ionChange': [{ type: core_1.Output },],
        };
        return SplitPane;
    }(ion_1.Ion));
    exports.SplitPane = SplitPane;
});
//# sourceMappingURL=split-pane.js.map